export class MuseError extends Error {
  fmt(): string {
    return `-- ERROR -- \nDetails: ${this.message}`;
  }
}

export class MusePluginError extends MuseError {
  plugin: string;

  constructor(message: string, plugin: string) {
    super(message);
    this.plugin = plugin;
  }

  fmt(): string {
    return `-- PLUGIN ERROR --\Plugin: ${this.plugin}\nDetails: ${this.message}`;
  }
}

export class MuseFileError extends MuseError {
  filePath: string;

  constructor(message: string, filePath: string) {
    super(message);
    this.filePath = filePath;
  }

  fmt(): string {
    return `-- FILE ERROR --\nFile Path: ${this.filePath}\nDetails: ${this.message}`;
  }
}

export class MuseFileNotFoundError extends MuseFileError {
  constructor(filePath: string) {
    super("File not found", filePath);
    this.message = "File does not exist";
    this.filePath = filePath;
  }
}

export class CLIError extends MuseError {}
